@@ -308,8 +308,14 @@ folder_registry_new (const gchar *account_uri,
 }
 
 static void
-on_replied (GError *error, gpointer user_data) 
-{ 
+on_replied (GError   *error,
+	    gpointer  user_data)
+{
+	if (error) {
+		g_warning ("Error updating data: %s\n", error->message);
+		g_error_free (error);
+	}
+
 	g_object_unref (user_data);
 }
 
@@ -319,9 +325,10 @@ send_sparql_update (TrackerEvolutionPlugin *self, const gchar *sparql)
 	TrackerEvolutionPluginPrivate *priv = TRACKER_EVOLUTION_PLUGIN_GET_PRIVATE (self);
 
 	if (priv->client) {
-		tracker_resources_batch_sparql_update_async (priv->client, sparql,
-		                                             on_replied, 
-		                                             g_object_ref (self));
+		dbus_g_proxy_call_no_reply (priv->client->proxy_resources,
+					    "SparqlUpdate",
+					    G_TYPE_STRING, sparql,
+					    G_TYPE_INVALID);
 	}
 }
 
@@ -337,12 +344,11 @@ send_sparql_commit (TrackerEvolutionPlugin *self, gboolean update)
 			                                 "WHERE { <" DATASOURCE_URN "> a nie:InformationElement ; nie:contentLastModified ?d } \n"
 			                                 "INSERT { <" DATASOURCE_URN "> nie:contentLastModified \"%s\" }",
 			                                 date_s);
-			g_free (date_s);
-			tracker_resources_batch_sparql_update_async (priv->client, update, 
-			                                             on_replied, 
-			                                             g_object_ref (self));
+
+			send_sparql_update (self, update);
 
 			g_free (update);
+			g_free (date_s);
 		}
 
 		tracker_resources_batch_commit_async (priv->client, on_replied, 
@@ -692,16 +698,9 @@ on_folder_summary_changed (CamelFolder *folder,
 
 			send_sparql_update (info->self, tracker_sparql_builder_get_result (sparql));
 
-/*
-			I saw a crash here, can't figure out why, it was
-			in strcmp of g_object_set (maybe multi-threading
-			of Camel is involved?)
-
-			g_object_set (info->self, "progress", 
-			              (gdouble) (merged->len - i) / merged->len,
-			              "status", _("Updating"), 
+			g_object_set (info->self, "progress",
+			              (gdouble) i / merged->len,
 			              NULL);
-*/
 
 			g_object_unref (sparql);
 
@@ -739,8 +738,8 @@ on_folder_summary_changed (CamelFolder *folder,
 
 	send_sparql_commit (info->self, TRUE);
 
-	/* g_object_set (info->self, "progress", 
-	              1.0, NULL); */
+	g_object_set (info->self, "progress",
+	              1.0, NULL);
 
 	g_free (em_uri);
 }
@@ -806,10 +805,12 @@ many_idle_handler (gpointer user_data)
 				priv->total_popped = priv->of_total;
 			}
 
-			g_object_set (user_data, "progress", 
-			              (gdouble) (priv->of_total - priv->total_popped) / priv->of_total,
-			              "status", _("Updating"), 
+#if 0
+			g_object_set (user_data, "progress",
+			              (gdouble) priv->total_popped / priv->of_total,
+			              "status", _("Updating"),
 			              NULL);
+#endif
 
 			send_sparql_update (user_data, query);
 		} else {
@@ -1023,6 +1024,8 @@ introduce_walk_folders_in_folder (TrackerEvolutionPlugin *self,
 						g_free(name);
 						g_free(value);
 					}
+
+					g_free (uri);
 					g_free (p);
 
 					tracker_sparql_builder_insert_close (sparql);
@@ -1075,11 +1078,13 @@ introduce_walk_folders_in_folder (TrackerEvolutionPlugin *self,
 
 				priv->of_total++;
 
+#if 0
 				if (priv->of_total > priv->total_popped) {
-					g_object_set (self, "progress", 
-					              (gdouble) (priv->of_total - priv->total_popped) / priv->of_total,
+					g_object_set (self, "progress",
+					              (gdouble) priv->total_popped / priv->of_total,
 					              NULL);
 				}
+#endif
 
 				if (start_handler) {
 					start_many_handler (self);
