@@ -23,6 +23,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <tracker-miner-fs/tracker-config.h>
+#include <tracker-status-icon/tracker-icon-config.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <stdlib.h>
@@ -43,6 +44,8 @@
 
 extern TrackerConfig* config;
 TrackerConfig* config = NULL;
+extern TrackerIconConfig* icon_config;
+TrackerIconConfig* icon_config = NULL;
 extern GtkWindow* window;
 GtkWindow* window = NULL;
 extern GtkCheckButton* checkbutton_enable_index_on_battery_first_time;
@@ -85,8 +88,16 @@ extern GtkTreeView* treeview_ignored_files;
 GtkTreeView* treeview_ignored_files = NULL;
 extern GtkToggleButton* togglebutton_home;
 GtkToggleButton* togglebutton_home = NULL;
+extern GtkRadioButton* radiobutton_display_never;
+GtkRadioButton* radiobutton_display_never = NULL;
+extern GtkRadioButton* radiobutton_display_active;
+GtkRadioButton* radiobutton_display_active = NULL;
+extern GtkRadioButton* radiobutton_display_always;
+GtkRadioButton* radiobutton_display_always = NULL;
 
 #define HOME_STRING "$HOME"
+void radiobutton_visibility_toggled_cb (GtkRadioButton* source);
+void initialize_visibility_radiobutton (void);
 void spinbutton_delay_value_changed_cb (GtkSpinButton* source);
 void checkbutton_enable_monitoring_toggled_cb (GtkCheckButton* source);
 void checkbutton_enable_thumbnails_toggled_cb (GtkCheckButton* source);
@@ -123,6 +134,33 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
+void radiobutton_visibility_toggled_cb (GtkRadioButton* source) {
+	g_return_if_fail (source != NULL);
+	if (gtk_toggle_button_get_active ((GtkToggleButton*) radiobutton_display_never)) {
+		tracker_icon_config_set_visibility (icon_config, 0);
+	} else {
+		if (gtk_toggle_button_get_active ((GtkToggleButton*) radiobutton_display_active)) {
+			tracker_icon_config_set_visibility (icon_config, 1);
+		} else {
+			tracker_icon_config_set_visibility (icon_config, 2);
+		}
+	}
+}
+
+
+void initialize_visibility_radiobutton (void) {
+	if (tracker_icon_config_get_visibility (icon_config) == 0) {
+		gtk_toggle_button_set_active ((GtkToggleButton*) radiobutton_display_never, TRUE);
+	} else {
+		if (tracker_icon_config_get_visibility (icon_config) == 1) {
+			gtk_toggle_button_set_active ((GtkToggleButton*) radiobutton_display_active, TRUE);
+		} else {
+			gtk_toggle_button_set_active ((GtkToggleButton*) radiobutton_display_always, TRUE);
+		}
+	}
+}
+
+
 void spinbutton_delay_value_changed_cb (GtkSpinButton* source) {
 	g_return_if_fail (source != NULL);
 	tracker_config_set_initial_sleep (config, gtk_spin_button_get_value_as_int (source));
@@ -457,6 +495,7 @@ void button_apply_clicked_cb (GtkButton* source) {
 	tracker_config_set_index_recursive_directories (config, _tmp4_ = model_to_slist (liststore_index_recursively));
 	__g_slist_free_g_free0 (_tmp4_);
 	tracker_config_save (config);
+	tracker_icon_config_save (icon_config);
 }
 
 
@@ -557,50 +596,58 @@ gint _main (char** args, int args_length1) {
 	gtk_init (&args_length1, &args);
 	{
 		TrackerConfig* _tmp0_;
+		TrackerIconConfig* _tmp1_;
 		GtkBuilder* builder;
-		GtkWindow* _tmp2_;
-		GObject* _tmp1_;
-		GtkCheckButton* _tmp4_;
-		GObject* _tmp3_;
-		GtkCheckButton* _tmp6_;
-		GObject* _tmp5_;
-		GtkSpinButton* _tmp8_;
-		GObject* _tmp7_;
-		GtkCheckButton* _tmp10_;
-		GObject* _tmp9_;
-		GtkCheckButton* _tmp12_;
-		GObject* _tmp11_;
-		GtkCheckButton* _tmp14_;
-		GObject* _tmp13_;
-		GtkCheckButton* _tmp16_;
-		GObject* _tmp15_;
-		GtkScale* _tmp18_;
-		GObject* _tmp17_;
-		GtkScale* _tmp20_;
-		GObject* _tmp19_;
-		GtkToggleButton* _tmp22_;
-		GObject* _tmp21_;
-		GtkTreeView* _tmp24_;
-		GObject* _tmp23_;
-		GtkTreeView* _tmp26_;
-		GObject* _tmp25_;
-		GtkTreeView* _tmp28_;
-		GObject* _tmp27_;
-		GtkTreeView* _tmp30_;
-		GObject* _tmp29_;
-		GtkTreeView* _tmp32_;
-		GObject* _tmp31_;
-		GtkListStore* _tmp34_;
-		GObject* _tmp33_;
-		GtkListStore* _tmp36_;
-		GObject* _tmp35_;
-		GtkListStore* _tmp38_;
-		GObject* _tmp37_;
-		GtkListStore* _tmp40_;
-		GObject* _tmp39_;
-		GtkListStore* _tmp42_;
-		GObject* _tmp41_;
+		GtkWindow* _tmp3_;
+		GObject* _tmp2_;
+		GtkCheckButton* _tmp5_;
+		GObject* _tmp4_;
+		GtkCheckButton* _tmp7_;
+		GObject* _tmp6_;
+		GtkSpinButton* _tmp9_;
+		GObject* _tmp8_;
+		GtkCheckButton* _tmp11_;
+		GObject* _tmp10_;
+		GtkCheckButton* _tmp13_;
+		GObject* _tmp12_;
+		GtkCheckButton* _tmp15_;
+		GObject* _tmp14_;
+		GtkCheckButton* _tmp17_;
+		GObject* _tmp16_;
+		GtkScale* _tmp19_;
+		GObject* _tmp18_;
+		GtkScale* _tmp21_;
+		GObject* _tmp20_;
+		GtkToggleButton* _tmp23_;
+		GObject* _tmp22_;
+		GtkRadioButton* _tmp25_;
+		GObject* _tmp24_;
+		GtkRadioButton* _tmp27_;
+		GObject* _tmp26_;
+		GtkRadioButton* _tmp29_;
+		GObject* _tmp28_;
+		GtkTreeView* _tmp31_;
+		GObject* _tmp30_;
+		GtkTreeView* _tmp33_;
+		GObject* _tmp32_;
+		GtkTreeView* _tmp35_;
+		GObject* _tmp34_;
+		GtkTreeView* _tmp37_;
+		GObject* _tmp36_;
+		GtkTreeView* _tmp39_;
+		GObject* _tmp38_;
+		GtkListStore* _tmp41_;
+		GObject* _tmp40_;
+		GtkListStore* _tmp43_;
+		GObject* _tmp42_;
+		GtkListStore* _tmp45_;
+		GObject* _tmp44_;
+		GtkListStore* _tmp47_;
+		GObject* _tmp46_;
+		GtkListStore* _tmp49_;
+		GObject* _tmp48_;
 		config = (_tmp0_ = tracker_config_new_with_domain ("tracker-miner-fs"), _g_object_unref0 (config), _tmp0_);
+		icon_config = (_tmp1_ = tracker_icon_config_new_with_domain ("tracker-status-icon"), _g_object_unref0 (icon_config), _tmp1_);
 		builder = gtk_builder_new ();
 		gtk_builder_add_from_file (builder, TRACKER_DATADIR G_DIR_SEPARATOR_S "tracker-preferences.ui", &_inner_error_);
 		if (_inner_error_ != NULL) {
@@ -608,48 +655,52 @@ gint _main (char** args, int args_length1) {
 			goto __catch0_g_error;
 			goto __finally0;
 		}
-		window = (_tmp2_ = _g_object_ref0 ((_tmp1_ = gtk_builder_get_object (builder, "tracker-preferences"), GTK_IS_WINDOW (_tmp1_) ? ((GtkWindow*) _tmp1_) : NULL)), _g_object_unref0 (window), _tmp2_);
-		checkbutton_enable_index_on_battery = (_tmp4_ = _g_object_ref0 ((_tmp3_ = gtk_builder_get_object (builder, "checkbutton_enable_index_on_battery"), GTK_IS_CHECK_BUTTON (_tmp3_) ? ((GtkCheckButton*) _tmp3_) : NULL)), _g_object_unref0 (checkbutton_enable_index_on_battery), _tmp4_);
-		checkbutton_enable_index_on_battery_first_time = (_tmp6_ = _g_object_ref0 ((_tmp5_ = gtk_builder_get_object (builder, "checkbutton_enable_index_on_battery_first_time"), GTK_IS_CHECK_BUTTON (_tmp5_) ? ((GtkCheckButton*) _tmp5_) : NULL)), _g_object_unref0 (checkbutton_enable_index_on_battery_first_time), _tmp6_);
+		window = (_tmp3_ = _g_object_ref0 ((_tmp2_ = gtk_builder_get_object (builder, "tracker-preferences"), GTK_IS_WINDOW (_tmp2_) ? ((GtkWindow*) _tmp2_) : NULL)), _g_object_unref0 (window), _tmp3_);
+		checkbutton_enable_index_on_battery = (_tmp5_ = _g_object_ref0 ((_tmp4_ = gtk_builder_get_object (builder, "checkbutton_enable_index_on_battery"), GTK_IS_CHECK_BUTTON (_tmp4_) ? ((GtkCheckButton*) _tmp4_) : NULL)), _g_object_unref0 (checkbutton_enable_index_on_battery), _tmp5_);
+		checkbutton_enable_index_on_battery_first_time = (_tmp7_ = _g_object_ref0 ((_tmp6_ = gtk_builder_get_object (builder, "checkbutton_enable_index_on_battery_first_time"), GTK_IS_CHECK_BUTTON (_tmp6_) ? ((GtkCheckButton*) _tmp6_) : NULL)), _g_object_unref0 (checkbutton_enable_index_on_battery_first_time), _tmp7_);
 		gtk_toggle_button_set_active ((GtkToggleButton*) checkbutton_enable_index_on_battery, tracker_config_get_index_on_battery (config));
 		gtk_widget_set_sensitive ((GtkWidget*) checkbutton_enable_index_on_battery_first_time, !gtk_toggle_button_get_active ((GtkToggleButton*) checkbutton_enable_index_on_battery));
 		gtk_toggle_button_set_active ((GtkToggleButton*) checkbutton_enable_index_on_battery_first_time, tracker_config_get_index_on_battery_first_time (config));
-		spinbutton_delay = (_tmp8_ = _g_object_ref0 ((_tmp7_ = gtk_builder_get_object (builder, "spinbutton_delay"), GTK_IS_SPIN_BUTTON (_tmp7_) ? ((GtkSpinButton*) _tmp7_) : NULL)), _g_object_unref0 (spinbutton_delay), _tmp8_);
+		spinbutton_delay = (_tmp9_ = _g_object_ref0 ((_tmp8_ = gtk_builder_get_object (builder, "spinbutton_delay"), GTK_IS_SPIN_BUTTON (_tmp8_) ? ((GtkSpinButton*) _tmp8_) : NULL)), _g_object_unref0 (spinbutton_delay), _tmp9_);
 		gtk_spin_button_set_increments (spinbutton_delay, (double) 1, (double) 1);
 		gtk_spin_button_set_value (spinbutton_delay, (double) tracker_config_get_initial_sleep (config));
-		checkbutton_enable_monitoring = (_tmp10_ = _g_object_ref0 ((_tmp9_ = gtk_builder_get_object (builder, "checkbutton_enable_monitoring"), GTK_IS_CHECK_BUTTON (_tmp9_) ? ((GtkCheckButton*) _tmp9_) : NULL)), _g_object_unref0 (checkbutton_enable_monitoring), _tmp10_);
+		checkbutton_enable_monitoring = (_tmp11_ = _g_object_ref0 ((_tmp10_ = gtk_builder_get_object (builder, "checkbutton_enable_monitoring"), GTK_IS_CHECK_BUTTON (_tmp10_) ? ((GtkCheckButton*) _tmp10_) : NULL)), _g_object_unref0 (checkbutton_enable_monitoring), _tmp11_);
 		gtk_toggle_button_set_active ((GtkToggleButton*) checkbutton_enable_monitoring, tracker_config_get_enable_monitors (config));
-		checkbutton_enable_thumbnails = (_tmp12_ = _g_object_ref0 ((_tmp11_ = gtk_builder_get_object (builder, "checkbutton_enable_thumbnails"), GTK_IS_CHECK_BUTTON (_tmp11_) ? ((GtkCheckButton*) _tmp11_) : NULL)), _g_object_unref0 (checkbutton_enable_thumbnails), _tmp12_);
+		checkbutton_enable_thumbnails = (_tmp13_ = _g_object_ref0 ((_tmp12_ = gtk_builder_get_object (builder, "checkbutton_enable_thumbnails"), GTK_IS_CHECK_BUTTON (_tmp12_) ? ((GtkCheckButton*) _tmp12_) : NULL)), _g_object_unref0 (checkbutton_enable_thumbnails), _tmp13_);
 		gtk_toggle_button_set_active ((GtkToggleButton*) checkbutton_enable_thumbnails, tracker_config_get_enable_thumbnails (config));
-		checkbutton_index_mounted_directories = (_tmp14_ = _g_object_ref0 ((_tmp13_ = gtk_builder_get_object (builder, "checkbutton_index_mounted_directories"), GTK_IS_CHECK_BUTTON (_tmp13_) ? ((GtkCheckButton*) _tmp13_) : NULL)), _g_object_unref0 (checkbutton_index_mounted_directories), _tmp14_);
+		checkbutton_index_mounted_directories = (_tmp15_ = _g_object_ref0 ((_tmp14_ = gtk_builder_get_object (builder, "checkbutton_index_mounted_directories"), GTK_IS_CHECK_BUTTON (_tmp14_) ? ((GtkCheckButton*) _tmp14_) : NULL)), _g_object_unref0 (checkbutton_index_mounted_directories), _tmp15_);
 		gtk_toggle_button_set_active ((GtkToggleButton*) checkbutton_index_mounted_directories, tracker_config_get_index_mounted_directories (config));
-		checkbutton_index_removable_media = (_tmp16_ = _g_object_ref0 ((_tmp15_ = gtk_builder_get_object (builder, "checkbutton_index_removable_media"), GTK_IS_CHECK_BUTTON (_tmp15_) ? ((GtkCheckButton*) _tmp15_) : NULL)), _g_object_unref0 (checkbutton_index_removable_media), _tmp16_);
+		checkbutton_index_removable_media = (_tmp17_ = _g_object_ref0 ((_tmp16_ = gtk_builder_get_object (builder, "checkbutton_index_removable_media"), GTK_IS_CHECK_BUTTON (_tmp16_) ? ((GtkCheckButton*) _tmp16_) : NULL)), _g_object_unref0 (checkbutton_index_removable_media), _tmp17_);
 		gtk_toggle_button_set_active ((GtkToggleButton*) checkbutton_index_removable_media, tracker_config_get_index_removable_devices (config));
-		hscale_disk_space_limit = (_tmp18_ = _g_object_ref0 ((_tmp17_ = gtk_builder_get_object (builder, "hscale_disk_space_limit"), GTK_IS_SCALE (_tmp17_) ? ((GtkScale*) _tmp17_) : NULL)), _g_object_unref0 (hscale_disk_space_limit), _tmp18_);
+		hscale_disk_space_limit = (_tmp19_ = _g_object_ref0 ((_tmp18_ = gtk_builder_get_object (builder, "hscale_disk_space_limit"), GTK_IS_SCALE (_tmp18_) ? ((GtkScale*) _tmp18_) : NULL)), _g_object_unref0 (hscale_disk_space_limit), _tmp19_);
 		gtk_range_set_value ((GtkRange*) hscale_disk_space_limit, (double) tracker_config_get_low_disk_space_limit (config));
-		hscale_throttle = (_tmp20_ = _g_object_ref0 ((_tmp19_ = gtk_builder_get_object (builder, "hscale_throttle"), GTK_IS_SCALE (_tmp19_) ? ((GtkScale*) _tmp19_) : NULL)), _g_object_unref0 (hscale_throttle), _tmp20_);
+		hscale_throttle = (_tmp21_ = _g_object_ref0 ((_tmp20_ = gtk_builder_get_object (builder, "hscale_throttle"), GTK_IS_SCALE (_tmp20_) ? ((GtkScale*) _tmp20_) : NULL)), _g_object_unref0 (hscale_throttle), _tmp21_);
 		gtk_range_set_value ((GtkRange*) hscale_throttle, (double) tracker_config_get_throttle (config));
-		togglebutton_home = (_tmp22_ = _g_object_ref0 ((_tmp21_ = gtk_builder_get_object (builder, "togglebutton_home"), GTK_IS_TOGGLE_BUTTON (_tmp21_) ? ((GtkToggleButton*) _tmp21_) : NULL)), _g_object_unref0 (togglebutton_home), _tmp22_);
-		treeview_index_recursively = (_tmp24_ = _g_object_ref0 ((_tmp23_ = gtk_builder_get_object (builder, "treeview_index_recursively"), GTK_IS_TREE_VIEW (_tmp23_) ? ((GtkTreeView*) _tmp23_) : NULL)), _g_object_unref0 (treeview_index_recursively), _tmp24_);
-		treeview_index_single = (_tmp26_ = _g_object_ref0 ((_tmp25_ = gtk_builder_get_object (builder, "treeview_index_single"), GTK_IS_TREE_VIEW (_tmp25_) ? ((GtkTreeView*) _tmp25_) : NULL)), _g_object_unref0 (treeview_index_single), _tmp26_);
-		treeview_ignored_directories = (_tmp28_ = _g_object_ref0 ((_tmp27_ = gtk_builder_get_object (builder, "treeview_ignored_directories"), GTK_IS_TREE_VIEW (_tmp27_) ? ((GtkTreeView*) _tmp27_) : NULL)), _g_object_unref0 (treeview_ignored_directories), _tmp28_);
-		treeview_ignored_directories_with_content = (_tmp30_ = _g_object_ref0 ((_tmp29_ = gtk_builder_get_object (builder, "treeview_ignored_directories_with_content"), GTK_IS_TREE_VIEW (_tmp29_) ? ((GtkTreeView*) _tmp29_) : NULL)), _g_object_unref0 (treeview_ignored_directories_with_content), _tmp30_);
-		treeview_ignored_files = (_tmp32_ = _g_object_ref0 ((_tmp31_ = gtk_builder_get_object (builder, "treeview_ignored_files"), GTK_IS_TREE_VIEW (_tmp31_) ? ((GtkTreeView*) _tmp31_) : NULL)), _g_object_unref0 (treeview_ignored_files), _tmp32_);
+		togglebutton_home = (_tmp23_ = _g_object_ref0 ((_tmp22_ = gtk_builder_get_object (builder, "togglebutton_home"), GTK_IS_TOGGLE_BUTTON (_tmp22_) ? ((GtkToggleButton*) _tmp22_) : NULL)), _g_object_unref0 (togglebutton_home), _tmp23_);
+		radiobutton_display_never = (_tmp25_ = _g_object_ref0 ((_tmp24_ = gtk_builder_get_object (builder, "radiobutton_display_never"), GTK_IS_RADIO_BUTTON (_tmp24_) ? ((GtkRadioButton*) _tmp24_) : NULL)), _g_object_unref0 (radiobutton_display_never), _tmp25_);
+		radiobutton_display_active = (_tmp27_ = _g_object_ref0 ((_tmp26_ = gtk_builder_get_object (builder, "radiobutton_display_active"), GTK_IS_RADIO_BUTTON (_tmp26_) ? ((GtkRadioButton*) _tmp26_) : NULL)), _g_object_unref0 (radiobutton_display_active), _tmp27_);
+		radiobutton_display_always = (_tmp29_ = _g_object_ref0 ((_tmp28_ = gtk_builder_get_object (builder, "radiobutton_display_always"), GTK_IS_RADIO_BUTTON (_tmp28_) ? ((GtkRadioButton*) _tmp28_) : NULL)), _g_object_unref0 (radiobutton_display_always), _tmp29_);
+		initialize_visibility_radiobutton ();
+		treeview_index_recursively = (_tmp31_ = _g_object_ref0 ((_tmp30_ = gtk_builder_get_object (builder, "treeview_index_recursively"), GTK_IS_TREE_VIEW (_tmp30_) ? ((GtkTreeView*) _tmp30_) : NULL)), _g_object_unref0 (treeview_index_recursively), _tmp31_);
+		treeview_index_single = (_tmp33_ = _g_object_ref0 ((_tmp32_ = gtk_builder_get_object (builder, "treeview_index_single"), GTK_IS_TREE_VIEW (_tmp32_) ? ((GtkTreeView*) _tmp32_) : NULL)), _g_object_unref0 (treeview_index_single), _tmp33_);
+		treeview_ignored_directories = (_tmp35_ = _g_object_ref0 ((_tmp34_ = gtk_builder_get_object (builder, "treeview_ignored_directories"), GTK_IS_TREE_VIEW (_tmp34_) ? ((GtkTreeView*) _tmp34_) : NULL)), _g_object_unref0 (treeview_ignored_directories), _tmp35_);
+		treeview_ignored_directories_with_content = (_tmp37_ = _g_object_ref0 ((_tmp36_ = gtk_builder_get_object (builder, "treeview_ignored_directories_with_content"), GTK_IS_TREE_VIEW (_tmp36_) ? ((GtkTreeView*) _tmp36_) : NULL)), _g_object_unref0 (treeview_ignored_directories_with_content), _tmp37_);
+		treeview_ignored_files = (_tmp39_ = _g_object_ref0 ((_tmp38_ = gtk_builder_get_object (builder, "treeview_ignored_files"), GTK_IS_TREE_VIEW (_tmp38_) ? ((GtkTreeView*) _tmp38_) : NULL)), _g_object_unref0 (treeview_ignored_files), _tmp39_);
 		setup_standard_treeview (treeview_index_recursively, _ ("Directory"));
 		setup_standard_treeview (treeview_index_single, _ ("Directory"));
 		setup_standard_treeview (treeview_ignored_directories, _ ("Directory"));
 		setup_standard_treeview (treeview_ignored_directories_with_content, _ ("Directory"));
 		setup_standard_treeview (treeview_ignored_files, _ ("File"));
-		liststore_index_recursively = (_tmp34_ = _g_object_ref0 ((_tmp33_ = gtk_builder_get_object (builder, "liststore_index_recursively"), GTK_IS_LIST_STORE (_tmp33_) ? ((GtkListStore*) _tmp33_) : NULL)), _g_object_unref0 (liststore_index_recursively), _tmp34_);
+		liststore_index_recursively = (_tmp41_ = _g_object_ref0 ((_tmp40_ = gtk_builder_get_object (builder, "liststore_index_recursively"), GTK_IS_LIST_STORE (_tmp40_) ? ((GtkListStore*) _tmp40_) : NULL)), _g_object_unref0 (liststore_index_recursively), _tmp41_);
 		fill_in_model (liststore_index_recursively, tracker_config_get_index_recursive_directories (config));
 		gtk_toggle_button_set_active (togglebutton_home, model_contains ((GtkTreeModel*) liststore_index_recursively, HOME_STRING));
-		liststore_index_single = (_tmp36_ = _g_object_ref0 ((_tmp35_ = gtk_builder_get_object (builder, "liststore_index_single"), GTK_IS_LIST_STORE (_tmp35_) ? ((GtkListStore*) _tmp35_) : NULL)), _g_object_unref0 (liststore_index_single), _tmp36_);
+		liststore_index_single = (_tmp43_ = _g_object_ref0 ((_tmp42_ = gtk_builder_get_object (builder, "liststore_index_single"), GTK_IS_LIST_STORE (_tmp42_) ? ((GtkListStore*) _tmp42_) : NULL)), _g_object_unref0 (liststore_index_single), _tmp43_);
 		fill_in_model (liststore_index_single, tracker_config_get_index_single_directories (config));
-		liststore_ignored_directories = (_tmp38_ = _g_object_ref0 ((_tmp37_ = gtk_builder_get_object (builder, "liststore_ignored_directories"), GTK_IS_LIST_STORE (_tmp37_) ? ((GtkListStore*) _tmp37_) : NULL)), _g_object_unref0 (liststore_ignored_directories), _tmp38_);
+		liststore_ignored_directories = (_tmp45_ = _g_object_ref0 ((_tmp44_ = gtk_builder_get_object (builder, "liststore_ignored_directories"), GTK_IS_LIST_STORE (_tmp44_) ? ((GtkListStore*) _tmp44_) : NULL)), _g_object_unref0 (liststore_ignored_directories), _tmp45_);
 		fill_in_model (liststore_ignored_directories, tracker_config_get_ignored_directories (config));
-		liststore_ignored_files = (_tmp40_ = _g_object_ref0 ((_tmp39_ = gtk_builder_get_object (builder, "liststore_ignored_files"), GTK_IS_LIST_STORE (_tmp39_) ? ((GtkListStore*) _tmp39_) : NULL)), _g_object_unref0 (liststore_ignored_files), _tmp40_);
+		liststore_ignored_files = (_tmp47_ = _g_object_ref0 ((_tmp46_ = gtk_builder_get_object (builder, "liststore_ignored_files"), GTK_IS_LIST_STORE (_tmp46_) ? ((GtkListStore*) _tmp46_) : NULL)), _g_object_unref0 (liststore_ignored_files), _tmp47_);
 		fill_in_model (liststore_ignored_files, tracker_config_get_ignored_files (config));
-		liststore_gnored_directories_with_content = (_tmp42_ = _g_object_ref0 ((_tmp41_ = gtk_builder_get_object (builder, "liststore_gnored_directories_with_content"), GTK_IS_LIST_STORE (_tmp41_) ? ((GtkListStore*) _tmp41_) : NULL)), _g_object_unref0 (liststore_gnored_directories_with_content), _tmp42_);
+		liststore_gnored_directories_with_content = (_tmp49_ = _g_object_ref0 ((_tmp48_ = gtk_builder_get_object (builder, "liststore_gnored_directories_with_content"), GTK_IS_LIST_STORE (_tmp48_) ? ((GtkListStore*) _tmp48_) : NULL)), _g_object_unref0 (liststore_gnored_directories_with_content), _tmp49_);
 		fill_in_model (liststore_gnored_directories_with_content, tracker_config_get_ignored_directories_with_content (config));
 		gtk_builder_connect_signals (builder, NULL);
 		gtk_widget_show_all ((GtkWidget*) window);
